@@ -1,9 +1,8 @@
 """Definition for "chat creation error"."""
 from typing import NoReturn
 
-from httpx import Response
-
 from botx.clients.methods.base import APIErrorResponse, BotXMethod
+from botx.clients.methods.wrappers import HTTPResponse
 from botx.exceptions import BotXAPIError
 
 
@@ -13,7 +12,7 @@ class ChatCreationError(BotXAPIError):
     message_template = "error while creating chat"
 
 
-def handle_error(method: BotXMethod, response: Response) -> NoReturn:
+def handle_error(method: BotXMethod, response: HTTPResponse) -> NoReturn:
     """Handle "chat creation error" error response.
 
     Arguments:
@@ -23,10 +22,10 @@ def handle_error(method: BotXMethod, response: Response) -> NoReturn:
     Raises:
         ChatCreationError: raised always.
     """
-    APIErrorResponse[dict].parse_obj(response.json())
+    APIErrorResponse[dict].parse_obj(response.json_body)
     raise ChatCreationError(
         url=method.url,
         method=method.http_method,
-        response_content=response.content,
+        response_content=response.bytes_body,
         status_content=response.status_code,
     )
