@@ -1,4 +1,5 @@
 """Method for editing sent event."""
+from typing import Optional
 from uuid import UUID
 
 from pydantic import Field
@@ -6,6 +7,7 @@ from pydantic import Field
 from botx.clients.methods.base import AuthorizedBotXMethod
 from botx.clients.types.message_payload import UpdatePayload
 from botx.clients.types.options import ResultOptions
+from botx.models.files import File
 
 
 class EditEvent(AuthorizedBotXMethod[str]):
@@ -21,5 +23,8 @@ class EditEvent(AuthorizedBotXMethod[str]):
     #: data for editing.
     result: UpdatePayload = Field(..., alias="payload")
 
+    #: file attached to message.
+    file: Optional[File] = None
+
     #: extra options for message.
     opts: ResultOptions = ResultOptions()
