@@ -55,6 +55,9 @@ class Message:
     #: ID of message event.
     sync_id: UUID = _message_proxy_property()
 
+    #: ID of message whose ui element was triggered to send this message.
+    source_sync_id: Optional[UUID] = _message_proxy_property()
+
     #: ID of bot that handles message in Express.
     bot_id: UUID = _message_proxy_property()
 
@@ -122,10 +125,6 @@ class Message:
             chat_id=self.group_chat_id,
         )
 
-        self.sent_from_button = (
-            self.data.get("ui", False) if isinstance(self.command.data, dict) else False
-        )
-
     @classmethod
     def from_dict(cls, message: dict, bot: "bots.Bot") -> Message:
         """Parse incoming dict into message.
@@ -146,7 +145,7 @@ class Message:
         Returns:
             bool: True if message is forward else False
         """
-        try:
+        try:  # noqa: WPS503
             self.entities.forward  # noqa: WPS428
         except AttributeError:
             return False
